"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SPCore = void 0;
var sp_core_library_1 = require("@microsoft/sp-core-library");
var CLASS_NAME = "SPCore";
/**
 * This class contains all the static methods that can be used in common.
 * Do not add any method that contains some specific logic
 */
var SPCore = /** @class */ (function () {
    function SPCore() {
    }
    /** Checks is the string is null or empty or undefined */
    SPCore.isEmptyString = function (value) {
        try {
            sp_core_library_1.Validate.isNonemptyString(value, 'value');
            return false;
        }
        catch (error) {
            return true;
        }
    };
    /** Checks is the object is null or not */
    SPCore.isNull = function (value) {
        try {
            sp_core_library_1.Validate.isNotNullOrUndefined(value, "value");
            return false;
        }
        catch (error) {
            return true;
        }
    };
    /** Method returns the internal name by replacing the space with _x0020_ */
    SPCore.getFieldInternalName = function (fieldName) {
        try {
            return sp_core_library_1.Text.replaceAll(fieldName, " ", '_x0020_');
        }
        catch (error) {
            // Cannot have the logging as the method is static and cannot have resources to intiate logger
            throw error;
        }
    };
    /** Method returns the parameter value from url */
    SPCore.getParameterValue = function (url, paramName) {
        var queryURL = new sp_core_library_1.UrlQueryParameterCollection(url);
        return queryURL.getValue(paramName);
    };
    /**
     * Returns the age from current date
     * @param dateString Date time string in ISO format
     */
    SPCore.calculateAge = function (dateString) {
        try {
            var paramAge = new Date(dateString);
            var ageDifMs = Date.now() - paramAge.getTime();
            var ageDate = new Date(ageDifMs); // miliseconds from epoch
            var age = ageDate.getUTCFullYear() - 1970;
            age = (age > 0) ? age : 0;
            return age;
        }
        catch (e) {
            return -1;
        }
    };
    /**
     * Returns the local storage (browser) object
     */
    SPCore.getLocalStorage = function () {
        if (!SPCore.isNull(typeof (Storage))) {
            return localStorage;
        }
        else {
            return undefined;
        }
    };
    return SPCore;
}());
exports.SPCore = SPCore;
